@@ -1,4 +1,4 @@
 from .service_registry import ServiceRegistry
-from .service_registry import InMemoryServiceRegistry
-from .nacos.nacos_service_registry import NacosServiceRegistry
+from .in_memory import InMemoryServiceRegistry
+from .nacos.nacos import NacosServiceRegistry
 __all__ = ["ServiceRegistry", "InMemoryServiceRegistry", "NacosServiceRegistry"]
\ No newline at end of file
